#! /usr/bin/perl -w

use strict;
use warnings;

my $bindir;
my $vmware;
my $line;

if (not open(CFG, '<', '/etc/vmware/locations')) {
	print STDERR "VMware installation database not found.\n";
	print STDERR "Building for VMware Workstation 3.2.x\n";
	print 'VME_V32';
	exit 0;
}
while (defined($line = <CFG>)) {
	chomp $line;
	if ($line =~ /^answer BINDIR (.*)$/) {
		$bindir = $1;
	}
}
close CFG;

if (not defined($bindir)) {
	print STDERR "Unable to find path to the VMware in installation database. Using 'vmware'.\n";
	$vmware = 'vmware';
} else {
	$vmware = $bindir.'/vmware';
}

my $type;
my $protocol;
my $build;
my $product;

open VMWARE, "$vmware -v < /dev/null 2>&1 |" or die 'Cannot start VMware';
while (defined($line = <VMWARE>)) {
	chomp $line;
	
	if ($line =~ /VMware (.*) protocol=(.*) build=(.*) product='(.*)'/) {
		($type, $protocol, $build, $product) = ($1, $2, $3, $4);
	} elsif (not defined($type) and $line =~ /VMware (.*) (\d+(?:\.\d+)*) (build-\d+)/) {
		($type, $protocol, $build, $product) = ($1, '6', $3, "$2 $3");
	}
}
close VMWARE;

if (not defined($type)) {
	print STDERR "VMware 2 or VMware Express detected, building for VMware 2, VMware Express and VMware 3.2\n";
	print 'VME_V32';
	exit 0;
}
if ($type =~ /GSX/i) {
	if ($product =~ /^1\./) {
		print STDERR "Building for VMware GSX Server 1.x.x\n";
		print 'VME_GSX1';
		exit 0;
	}
	if ($product =~ /^2\.0/) {
		print STDERR "Building for VMware GSX Server 2.0.x\n";
		print 'VME_GSX2';
		exit 0;
	}
	print STDERR "Unknown GSX Server $product detected. Building for VMware GSX Server 2.0.x\n";
	print 'VME_GSX2';
	exit 0;
} elsif ($type =~ /Workstation/i) {
	if ($product =~ /^3\.[01]\./) {
		print STDERR "Building for VMware Workstation 3.0.x\n";
		print 'VME_V3';
		exit 0;
	}
	if ($product =~ /^3\.2\./) {
		print STDERR "Building for VMware Workstation 3.2.x\n";
		print 'VME_V32';
		exit 0;
	}
	print STDERR "Unknown VMware Workstation $product detected. Building for VMware Workstation 3.2.x\n";
	print 'VME_V32';
	exit 0;
}
print STDERR "Unknown product ($type) detected, building for VMware 3.2\n";
print 'VME_V32';
exit 0;
